netapp_ontap.models.group_policy_object_restrict_anonymous API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.group_policy_object_restrict_anonymous`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class GroupPolicyObjectRestrictAnonymousSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the GroupPolicyObjectRestrictAnonymous object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `anonymous_access_to_shares_and_named_pipes_restricted: bool GET POST PATCH`

    Restrict anonymous access to shares and named pipes.

  `combined_restriction_for_anonymous_user: str GET POST PATCH`

    Combined restriction for anonymous user.

    Valid choices:

    - no_restriction
    - no_enumeration
    - no_access
  `no_enumeration_of_sam_accounts: bool GET POST PATCH`

    No enumeration of SAM accounts.

  `no_enumeration_of_sam_accounts_and_shares: bool GET POST PATCH`

    No enumeration of SAM accounts and shares.